import { Resource } from "aws-cdk-lib";
import * as iam from "aws-cdk-lib/aws-iam";
import * as route53 from "aws-cdk-lib/aws-route53";
import { Construct } from "constructs";
/**
 * Properties to create a DNS-validated Domain Identity of AWS SES Service.
 *
 * @experimental
 */
export interface DnsValidatedDomainIdentityProps {
    /**
     * Fully-qualified domain name to request a domain identity for.
     */
    readonly domainName: string;
    /**
     * Whether to configure DKIM on domain identity.
     * @default true
     */
    readonly dkim?: boolean;
    /**
     * Route 53 Hosted Zone used to perform DNS validation of the request.  The zone
     * must be authoritative for the domain name specified in the Domain Identity Request.
     */
    readonly hostedZone: route53.IHostedZone;
    /**
     * AWS region that will validate the domain identity. This is needed especially
     * for domain identity used for AWS SES services, which require the region
     * to be one of SES supported regions.
     *
     * @default the region the stack is deployed in.
     */
    readonly region?: string;
    /**
     * Role to use for the custom resource that creates the validated domain identity
     *
     * @default - A new role will be created
     */
    readonly customResourceRole?: iam.IRole;
}
/**
 * A domain identity managed by AWS SES.  Will be automatically
 * validated using DNS validation against the specified Route 53 hosted zone.
 */
export declare class DnsValidatedDomainIdentity extends Resource {
    readonly domainName: string;
    readonly dkim: boolean;
    readonly identityArn: string;
    private readonly hostedZoneId;
    private readonly normalizedZoneName;
    constructor(scope: Construct, id: string, props: DnsValidatedDomainIdentityProps);
}
